#webcam-monitor{
    display: none;
    position: fixed;
    top: 50%;
    left: 50%;
    margin-top: -150px;
    margin-left: -100px;
    border: 1px solid black;
    padding: 10px;
    background-color: #d3d3d3;
}
.camera-preview{
    border: 1px solid black;
        /*position: fixed;*/
}

